@@ -14,14 +14,28 @@ dbutils = get_dbutils(spark)
 		
 dicct = {}
 countt = 0
+inlen = 0
 def upda(path):
+    global dicct
+    dicct = {}
     for j in path.split(","):
         dicct[j.split("/")[-1]] = 0
     global countt
     countt = 1
+    global inlen
+    inlen = len(path.split(","))
     
 def sequence_run(path):
-
+    if len(path.split(",")) != inlen:
+        global dicct
+        dicct = {}
+        global countt
+        countt = 0
+    else:
+        if list(dicct.keys())!= [k.split("/")[-1] for k in path.split(",")]:
+            dicct = {}
+            countt = 0
+        
     if countt == 0:
         upda(path)
         for i in path.split(","):
@@ -30,22 +44,24 @@ def sequence_run(path):
                 try:
                     dbutils.notebook.run(i,1200)
                     dicct[i.split("/")[-1]] = 1
+                    print('\033[1m' + i.split("/")[-1] + u' \u2713' + '\033[0m')
                 except:
-                    print(i.split("/")[-1],"failed")
+                    print('\033[1m' + i.split("/")[-1] + " X" + '\033[0m')
                     dicct[i.split("/")[-1]] = 0
                     break
             else:
                 pass
     else:
-        for i in path.split(","):
-            if dicct[i.split("/")[-1]] == 0:
-                print("Running notebook %s" % i.split("/")[-1])
+        for j in path.split(","):
+            if dicct[j.split("/")[-1]] == 0:
+                print('\033[2m' + "Running notebook %s" % j.split("/")[-1])
                 try:
-                    dbutils.notebook.run(i,1200)
-                    dicct[i.split("/")[-1]] = 1
+                    dbutils.notebook.run(j,1200)
+                    dicct[j.split("/")[-1]] = 1
+                    print('\033[1m' + j.split("/")[-1] + u' \u2713' + '\033[0m')
                 except:
-                    print(i.split("/")[-1],"failed")
-                    dicct[i.split("/")[-1]] = 0
+                    print('\033[1m' + j.split("/")[-1] + " X" + '\033[0m')
+                    dicct[j.split("/")[-1]] = 0
                     break
             else:
                 pass
@@ -65,9 +81,10 @@ def parallel_run(filepath):
                     return dbutils.notebook.run(notebook.path, notebook.timeout, notebook.parameters)
                 else:
                     try:
-                        return dbutils.notebook.run(notebook.path, notebook.timeout)
+                        dbutils.notebook.run(notebook.path, notebook.timeout)
+						print('\033[1m' + str(notebook.path).split("/")[-1] + u' \u2713' + '\033[0m')
                     except:
-                        print(str(notebook.path).split("/")[-1], 'failed')
+                        print('\033[1m' + str(notebook.path).split("/")[-1] + ' X' + '\033[0m')
             except Exception:
                 if notebook.retry < 1:
                     raise
